#
# spec file for package jcip-annotations
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jcip-annotations
Version:        1.0.1
Release:        2.1
Summary:        A clean room implementation of the JCIP Annotations
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/stephenc/jcip-annotations
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local
BuildArch:      noarch

%description
A clean room implementation of the JCIP Annotations based entirely on the
specification provided by the javadocs.

%package javadoc
Summary:        API documentation for %{name}
Group:          Development/Libraries/Java

%description javadoc
A clean room implementation of the JCIP Annotations based entirely on the
specification provided by the javadocs.

This package contains the API documentation.

%prep
%setup -q
cp %{SOURCE1} build.xml

# Remove unnecessary dependency on parent POM
%pom_remove_parent

# Remove unnecessary dependency on JUnit
%pom_remove_dep junit:junit

%build
ant jar javadoc

%install
# jars
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 target/%{name}.jar %{buildroot}%{_javadir}/%{name}.jar

# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}
install -pm 0644 pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap JPP-%{name}.pom %{name}.jar -a "net.jcip:%{name}"

# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

%files -f .mfiles
%license LICENSE.txt
%doc README.md

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE.txt

%changelog
* Thu Dec 19 2024 Fridrich Strba <fstrba@suse.com>
- Use ant to build
* Wed Dec 18 2024 Fridrich Strba <fstrba@suse.com>
- Switch to clean room implementation, as original implementation
  uses CC-BY-2.5 licence. The clean room implementation is under
  Apache-2.0
* Sun Dec  8 2024 Fridrich Strba <fstrba@suse.com>
- The pom file is simple, so it does not need to be installed
  using the %%%%mvn_install_pom macro
* Wed Dec  4 2024 Fridrich Strba <fstrba@suse.com>
- Add alias to the other implementation out there
* Mon Sep 23 2024 Fridrich Strba <fstrba@suse.com>
- Use SOURCE_DATE_EPOCH for reproducible builds
- Clean the spec file, fix download urls and redownload the sources
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with source/target levels 8
* Mon Sep 18 2017 fstrba@suse.com
- Specify java source and target 1.6: build with all java-devel
  providers until jdk9
- Resurect the javadoc package
- Fix rpmlint error and clean spec file
* Fri May 19 2017 tchvatal@suse.com
- Fix build with new javapackages-tools
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Tue Sep 10 2013 mvyskocil@suse.com
- use add_maven_depmap from javapackages-tools
- drop javadoc build, N/A with gcc-java
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Mon Feb 27 2012 cfarrell@suse.com
- license update: CC-BY-2.5
  Most of the pattern matches in the package are for CC-BY-2.5, not
  CC-BY-3.0
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Tue Dec  7 2010 coolo@novell.com
- switch rpm group
* Wed Jun  3 2009 mvyskocil@suse.cz
- Initial SUSE packaging based on jpp5.0
